@@ -8,7 +8,7 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 __all__ = ['generate_ai_plugins_classes']
 
-IF_PLUGINS = ["GDF032022", "ACF082023", "TAB072023", "QLC092022", "GDM082023", "UIP072021", "ADO112023", "OVM012024", "ACS042023", "ZBA042022", "GBA032023", "AHD062022", "ODI032024", "SNF092022", "ADF062021", "ANS032024", "JEN022024", "DBT042023", "COM032023", "AAT052023", "GBQ102022", "ZVM062022", "GDR052023", "MFL022023", "BAK092023", "ALM012024", "TER102023", "ZFN032022", "MFW022023", "ICS032022", "GDQ112023", "ABY122023", "ABK042023", "ADB112022", "ABA092022", "GDU102023", "TDM052022", "ASM0220223", "ADP122022", "ZLA112022", "GWF092023", "GLU062021", "ZSY062022", "ZML022023", "AEM072022", "KBN062023", "GFU012023", "AQS012023", "GDP042022", "GVM062022", "RST062023", "MBI042022", "ADY122023", "ATR122022", "AAR072022", "BOO032022", "ZRM082023", "AEC082022", "SOP072023", "ASQ032024", "AMM082023", "ASF012023", "ZDX112021", "SFI122022", "DBX032022"]
+IF_PLUGINS = ['TDM052022', 'ZFN032022', 'ADO112023', 'AAT052023', 'DBX032022', 'ALM012024', 'TER102023', 'GDM082023', 'ACS042023', 'GDR052023', 'SOP072023', 'TAB072023', 'ZLA112022', 'ANS032024', 'ADF062021', 'ABY122023', 'ODI032024', 'AHD062022', 'GWF092023', 'ICS032022', 'ADY122023', 'ZML022023', 'ADP122022', 'ZRM082023', 'BAK092023', 'SNF092022', 'ASM0220223', 'ZDX112021', 'UIP072021', 'OVM012024', 'DBT042023', 'ASF012023', 'MFW022023', 'COM032023', 'GDU102023', 'AEC082022', 'BOO032022', 'MFL022023', 'ABK042023', 'ABA092022', 'SFI122022', 'KBN062023', 'GDP042022', 'AEM072022', 'GVM062022', 'GDF032022', 'ZSY062022', 'QLC092022', 'MBI042022', 'ATR122022', 'GLU062021', 'AAR072022', 'AMM082023', 'ZBA042022', 'ACF082023', 'GDQ112023', 'GFU012023', 'ZVM062022', 'AQS012023', 'RST062023', 'ASQ032024', 'GBQ102022', 'JEN022024', 'GBA032023', 'ADB112022']
 
 
 imports_str = '''from aapi import *
